# APIs

## KGs

Top-level:

- [DONE] Get
- [DONE] List

On a KG object:

- [DONE] Get topology
- [DONE] Resume from a snapshot
- [DONE] Resume empty
- Get status
- List snapshots
- Delete

## Queries

- [DONE] Run
- [DONE] Build a Flow
- [DONE] Build a Workflow
- [DONE] Apply coordinates

## Data catalogs

Top-level:

- Create
- List
- Get

Collection management:

- Create collection
- Delete collection
- Retrieve data in collection

Uploading data:

- Upload file to catalog
- Upload file to collection

Management:

- Delete
